@@ -67,7 +67,7 @@ class Eaves:
         }
         self.res: Optional[tuple[int, int]] = None
         self.config_file: Optional[ConfigFile] = None
-        self._before_startup: Optional[Callable] = None
+        self._on_startup: Optional[Callable] = None
         self._before_shutdown: Optional[Callable] = None
         self.handlers_to_load: list[str] = []
 
@@ -75,8 +75,8 @@ class Eaves:
     def load_files(self, files: list[str]) -> None:
         self.handlers_to_load = files
 
-    def before_startup(self, func: Callable) -> Callable:
-        self._before_startup = func
+    def on_startup(self, func: Callable) -> Callable:
+        self._on_startup = func
         return func
     
     def before_shutdown(self, func: Callable) -> Callable:
@@ -154,8 +154,8 @@ class Eaves:
         self.screen = display.set_mode(self.res, window_type)
         display.set_caption(window_caption)
 
-        if self._before_startup:
-            self._before_startup()
+        if self._on_startup:
+            self._on_startup()
 
         while self.running:
 
